@@ -2,7 +2,7 @@
 /******************************************************************************\
  * $RCSfile: text.cpp,v $
  *
- * Copyright (C) 1999-2002  Martin Blais <blais@iro.umontreal.ca>
+ * Copyright (C) 1999-2003  Martin Blais <blais@furius.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -150,22 +150,8 @@ inline void rentxt(
          &brect
       );
 
-#if 0 
 #ifdef XX_DEBUG
-      {
-         QRect borect = fm.boundingRect( str, rlen );
-         QSize bsize = fm.size( Qt::SingleLine, str, rlen );
-         XX_TRACE( "AHAHAH "
-                   << borect.height() << " "
-                   << bsize.height() << " "
-                   << brect.height() << " "
-                   << fm.lineSpacing() );
-      }
-#endif
-#endif
-
-#ifdef XX_DEBUG
-      // FIXME remove
+      // For debug only, could be removed.
       if ( flag ) {
          QPen pushPen = p.pen();
          QPen stipplePen = pushPen;
@@ -226,6 +212,7 @@ XxText::XxText(
    setBackgroundMode( NoBackground );
 #endif
 
+#if (QT_VERSION >= 0x030000)
    // Initialize clipboard to use mouse selection.
    //
    // We do this multiple times for nothing, but I'd rather have it here
@@ -235,6 +222,7 @@ XxText::XxText(
 
    // Bind clear to change signal.
    connect( cb, SIGNAL(selectionChanged()), this, SLOT(clearRegionSelect()) );
+#endif
 }
 
 //------------------------------------------------------------------------------
